@@ -74,6 +74,7 @@ class BSBLAN:
     _api_data: APIConfig | None = None
     _initialized: bool = False
     _api_validator: APIValidator = field(init=False)
+    _temperature_unit: str = "°C"
 
     async def __aenter__(self) -> Self:
         """Enter the context manager.
@@ -216,6 +217,22 @@ class BSBLAN:
                 self._min_temp,
                 self._max_temp,
             )
+            # also set unit of temperature
+            if static_values.min_temp.unit in ("&deg;C", "°C"):
+                self._temperature_unit = "°C"
+            else:
+                self._temperature_unit = "°F"
+
+    async def get_temperature_unit(self) -> str:
+        """Get the unit of temperature.
+
+        Returns:
+            str: The unit of temperature.
+
+        """
+        if self._temperature_unit is None:
+            await self._initialize_temperature_range()
+        return self._temperature_unit
 
     async def _initialize_api_data(self) -> APIConfig:
         """Initialize and cache the API data.
@@ -536,6 +553,7 @@ class BSBLAN:
         self,
         nominal_setpoint: float | None = None,
         reduced_setpoint: float | None = None,
+        operating_mode: str | None = None,
     ) -> None:
         """Change the state of the hot water system through BSB-Lan.
 
@@ -547,12 +565,14 @@ class BSBLAN:
         self._validate_single_parameter(
             nominal_setpoint,
             reduced_setpoint,
+            operating_mode,
             error_msg=MULTI_PARAMETER_ERROR_MSG,
         )
 
         state = self._prepare_hot_water_state(
             nominal_setpoint,
             reduced_setpoint,
+            operating_mode,
         )
         await self._set_hot_water_state(state)
 
@@ -560,6 +580,7 @@ class BSBLAN:
         self,
         nominal_setpoint: float | None,
         reduced_setpoint: float | None,
+        operating_mode: str | None,
     ) -> dict[str, Any]:
         """Prepare the hot water state for setting.
 
@@ -583,6 +604,14 @@ class BSBLAN:
             state.update(
                 {"Parameter": "1612", "Value": str(reduced_setpoint), "Type": "1"},
             )
+        if operating_mode is not None:
+            state.update(
+                {
+                    "Parameter": "1600",
+                    "EnumValue": operating_mode,
+                    "Type": "1",
+                },
+            )
         if not state:
             raise BSBLANError(NO_STATE_ERROR_MSG)
         return state
